@@ -69,7 +69,7 @@ class Wimby:
                     previous = float(comparison.get(token, 0))
                     change = 0
                     if previous > 0:
-                        change = ((previous - rank) / rank) * 100
+                        change = ((rank - previous) / previous) * 100
                     fmovement = f"{movement:,.2f}"
                     while len(fmovement) < padding:
                         fmovement = f" {fmovement}"
